@@ -88,7 +88,8 @@ class YextClient:
 
     def search_answers_vertical(self, query: str, experience_key: str,
                                 vertical_key: str, locale: str = 'en',
-                                version: str = 'PRODUCTION'):
+                                version: str = 'PRODUCTION', 
+                                headers: Optional[dict] = {}):
         '''
         Searches the Answers vertical search endpoint.
 
@@ -117,12 +118,13 @@ class YextClient:
             'version': version,
             'verticalKey': vertical_key
         }
-        response = requests.get(endpoint, params=params).json()
+        response = requests.get(endpoint, params=params, headers=headers).json()
         return response
 
     def search_answers_universal(self, query: str, experience_key: str,
                                  locale: str = 'en',
-                                 version: str = 'PRODUCTION'):
+                                 version: str = 'PRODUCTION',
+                                 headers: Optional[dict] = {}):
         '''
         Searches the Answers universal search endpoint.
 
@@ -148,7 +150,7 @@ class YextClient:
             'experienceKey': experience_key,
             'version': version
         }
-        response = requests.get(endpoint, params=params)
+        response = requests.get(endpoint, params=params, headers=headers)
         results = AnswersUniversalResults(response)
         return results
 
@@ -241,7 +243,7 @@ class YextClient:
         self._validate_response(response)
         return response.json()
 
-    def update_entity(self, id: str, profile: dict,
+    def update_entity(self, profile: dict, id: Optional[str] = None, 
                       format: Optional[Literal[FormatOptions]] = 'html',
                       strip_unsupported_formats: Optional[bool] = False,
                       **kwargs):
@@ -250,12 +252,14 @@ class YextClient:
 
         Args:
         ----
-            id: str
-                The entity ID of the profile.
             profile:
                 The JSON of the entity profile, including the `meta` which
                 details the entity ID and country code, as well as the body
                 where the keys are the API names of the fields.
+            id: str
+                The entity ID of the profile. If this is not provided, then 
+                it is inferred from the meta.id of the profile itself. If 
+                this is not present, an error is raised.
             format: str
                 The format for rich text fields. Either 'html' or or 'markdown'.
             strip_unsupported_formats: bool, default False
@@ -267,6 +271,12 @@ class YextClient:
             'v': self.v,
             'format': format
         }
+        if not id:
+            try:
+                id = profile['meta']['id']
+            except ValueError:
+                msg = 'Entity ID must be provided either as a keyword argument or part of the "meta" object of the profile.' 
+                raise YextException(msg)
         endpoint = self.KNOWLEDGE_ENDPOINTS[self.env]['entity'].format(entity_id=id)
         response = requests.put(endpoint, params=params, json=profile)
         self._validate_response(response)
